@@ -307,66 +307,68 @@ class WAxisManager(Ui_WAxisManager, QWidget):
                         self.w_axis_1.axes_list[i] = ifft_dict[axis]
             self.gen_slice_op(is_refresh=False)
 
-        elif axis_changed == "axis 2":  # and "FFT" in [
-            #     self.w_axis_2.c_action.itemText(i)
-            #     for i in range(self.w_axis_2.c_action.count())
-            # ]:
-            action_selected = self.w_axis_2.get_current_action_name()
-            self.w_axis_1.set_action(action_selected)
-            if action_selected == "FFT":
-                if self.w_axis_1.axis_selected in fft_dict:
-                    if self.w_axis_1.axis_selected in self.w_axis_1.axes_list:
-                        self.w_axis_1.axes_list[
-                            self.w_axis_1.axes_list.index(self.w_axis_1.axis_selected)
-                        ] = fft_dict[self.w_axis_1.axis_selected]
-                        self.w_axis_1.axis_selected = fft_dict[
-                            self.w_axis_1.axis_selected
-                        ]
-                    else:
-                        self.w_axis_1.axis_selected = fft_dict[
-                            self.w_axis_1.axis_selected
-                        ]
-                elif self.w_axis_1.axis_selected in ifft_dict:
-                    if (
-                        self.w_axis_1.axis_selected not in self.w_axis_1.axes_list
-                        and ifft_dict[self.w_axis_1.axis_selected]
-                        in self.w_axis_1.axes_list
+        elif axis_changed == "axis 2" and self.w_axis_2.get_axis_selected() != "None":
+            if self.w_axis_2.get_axis_selected() != "None":
+                action_selected = self.w_axis_2.get_current_action_name()
+                self.w_axis_1.set_action(action_selected)
+                if action_selected == "FFT":
+                    if self.w_axis_1.axis_selected in fft_dict:
+                        if self.w_axis_1.axis_selected in self.w_axis_1.axes_list:
+                            self.w_axis_1.axes_list[
+                                self.w_axis_1.axes_list.index(
+                                    self.w_axis_1.axis_selected
+                                )
+                            ] = fft_dict[self.w_axis_1.axis_selected]
+                            self.w_axis_1.axis_selected = fft_dict[
+                                self.w_axis_1.axis_selected
+                            ]
+                        else:
+                            self.w_axis_1.axis_selected = fft_dict[
+                                self.w_axis_1.axis_selected
+                            ]
+                    elif self.w_axis_1.axis_selected in ifft_dict:
+                        if (
+                            self.w_axis_1.axis_selected not in self.w_axis_1.axes_list
+                            and ifft_dict[self.w_axis_1.axis_selected]
+                            in self.w_axis_1.axes_list
+                        ):
+                            self.w_axis_1.axes_list[
+                                self.w_axis_1.axes_list.index(
+                                    ifft_dict[self.w_axis_1.axis_selected]
+                                )
+                            ] = self.w_axis_1.axis_selected
+                else:
+                    if self.w_axis_1.axis_selected in ifft_dict and (
+                        self.w_axis_2.axis_selected in fft_dict
+                        or self.w_axis_2.axis_selected in ifft_dict
                     ):
-                        self.w_axis_1.axes_list[
-                            self.w_axis_1.axes_list.index(
-                                ifft_dict[self.w_axis_1.axis_selected]
-                            )
-                        ] = self.w_axis_1.axis_selected
-            else:
-                if self.w_axis_1.axis_selected in ifft_dict and (
-                    self.w_axis_2.axis_selected in fft_dict
-                    or self.w_axis_2.axis_selected in ifft_dict
-                ):
-                    if self.w_axis_1.axis_selected in self.w_axis_1.axes_list:
-                        self.w_axis_1.axes_list[
-                            self.w_axis_1.axes_list.index(self.w_axis_1.axis_selected)
-                        ] = ifft_dict[self.w_axis_1.axis_selected]
-                        self.w_axis_1.axis_selected = ifft_dict[
-                            self.w_axis_1.axis_selected
-                        ]
-                    else:
-                        self.w_axis_1.axis_selected = ifft_dict[
-                            self.w_axis_1.axis_selected
-                        ]
-                elif self.w_axis_1.axis_selected in fft_dict and (
-                    self.w_axis_2.axis_selected in fft_dict
-                    or self.w_axis_2.axis_selected in ifft_dict
-                ):
-                    if (
-                        self.w_axis_1.axis_selected not in self.w_axis_1.axes_list
-                        and fft_dict[self.w_axis_1.axis_selected]
-                        in self.w_axis_1.axes_list
+                        if self.w_axis_1.axis_selected in self.w_axis_1.axes_list:
+                            self.w_axis_1.axes_list[
+                                self.w_axis_1.axes_list.index(
+                                    self.w_axis_1.axis_selected
+                                )
+                            ] = ifft_dict[self.w_axis_1.axis_selected]
+                            self.w_axis_1.axis_selected = ifft_dict[
+                                self.w_axis_1.axis_selected
+                            ]
+                        else:
+                            self.w_axis_1.axis_selected = ifft_dict[
+                                self.w_axis_1.axis_selected
+                            ]
+                    elif self.w_axis_1.axis_selected in fft_dict and (
+                        self.w_axis_2.axis_selected in fft_dict
+                        or self.w_axis_2.axis_selected in ifft_dict
                     ):
-                        self.w_axis_1.axes_list[
-                            self.w_axis_1.axes_list.index(
-                                fft_dict[self.w_axis_1.axis_selected]
-                            )
-                        ] = self.w_axis_1.axis_selected
+                        if (
+                            self.w_axis_1.axis_selected not in self.w_axis_1.axes_list
+                            and fft_dict[self.w_axis_1.axis_selected]
+                            in self.w_axis_1.axes_list
+                        ):
+                            self.w_axis_1.axes_list[
+                                self.w_axis_1.axes_list.index(
+                                    fft_dict[self.w_axis_1.axis_selected]
+                                )
+                            ] = self.w_axis_1.axis_selected
                 # Make sure that all axes are reset to ifft
                 for i, axis in enumerate(self.w_axis_2.axes_list):
                     if axis in ifft_dict and (
